@@ -14,15 +14,18 @@ specific language governing permissions and limitations
 under the License.
 """
 import datetime as dt
+import logging
+
 import pandas as pd
 from abc import ABCMeta
 import inflection
 from typing import Optional, Union
 from gs_quant.base import Base
 from gs_quant.api.fred.fred_query import FredQuery
-from gs_quant.target.common import FieldFilterMap
 from gs_quant.target.data import DataQuery, MDAPIDataQuery
 
+_logger = logging.getLogger(__name__)
+
 
 class DataApi(metaclass=ABCMeta):
     @classmethod
@@ -51,6 +54,7 @@ class DataApi(metaclass=ABCMeta):
             end: Optional[Union[dt.date, dt.datetime]] = None,
             as_of: Optional[dt.datetime] = None,
             since: Optional[dt.datetime] = None,
+            restrict_fields: bool = False,
             **kwargs
     ):
         end_is_time = isinstance(end, dt.datetime)
@@ -84,18 +88,19 @@ class DataApi(metaclass=ABCMeta):
                 format="MessagePack"
             )
 
-        where = FieldFilterMap()
         query_properties = query.properties()
-        where_properties = where.properties()
-
+        query.where = dict()
         for field, value in kwargs.items():
             snake_case_field = inflection.underscore(field)
             if snake_case_field in query_properties:
                 setattr(query, snake_case_field, value)
-            elif snake_case_field in where_properties:
-                setattr(where, snake_case_field, value)
-                query.where = where
             else:
-                raise ValueError('Invalid query field: ' + field)
+                query.where[field] = value
+
+        if getattr(query, 'fields', None) is not None:
+            try:
+                query.restrict_fields = restrict_fields
+            except AttributeError as e:
+                _logger.debug('unable to set restrict_fields', exc_info=e)
 
         return query
