@@ -14,7 +14,7 @@ specific language governing permissions and limitations
 under the License.
 """
 
-from gs_quant.target.common import BusinessDayConvention, Currency, DayCountFraction, AssetClass, AssetType,\
+from gs_quant.target.common import BusinessDayConvention, BuySell, Currency, DayCountFraction, AssetClass, AssetType,\
     OptionStyle, OptionType, PayReceive, PricingLocation, SwapClearingHouse, SwapSettlement, XRef
 from gs_quant.target.risk import CountryCode
 from enum import Enum
