@@ -14,17 +14,21 @@ specific language governing permissions and limitations
 under the License.
 """
 from gs_quant.base import Priceable, RiskKey
-from gs_quant.markets import PricingCache, PricingContext
-from gs_quant.risk import DataFrameWithInfo, DollarPrice, ErrorValue, FloatWithInfo, Price, RiskMeasure, SeriesWithInfo
-from gs_quant.risk.results import MultipleRiskMeasureFuture
+from gs_quant.markets import MarketDataCoordinate, HistoricalPricingContext, PricingCache, PricingContext
+from gs_quant.risk import DataFrameWithInfo, DollarPrice, ErrorValue, FloatWithInfo, MarketDataAssets, Price,\
+    ResolvedInstrumentValues, RiskMeasure, SeriesWithInfo
+from gs_quant.risk.results import MultipleRiskMeasureFuture, PricingFuture
 
 from gs_quant.session import GsSession
 
 from abc import ABCMeta
-from concurrent.futures import Future
-from typing import Iterable, Optional, Union
+import copy
+import itertools
+import logging
+from typing import Iterable, Optional, Tuple, Union
 
 __asset_class_and_type_to_instrument = {}
+_logger = logging.getLogger(__name__)
 
 
 class PriceableImpl(Priceable, metaclass=ABCMeta):
@@ -52,8 +56,8 @@ class PriceableImpl(Priceable, metaclass=ABCMeta):
             attr = getattr(super().__getattribute__('__class__'), name, None)
             if attr and isinstance(attr, property):
                 resolved_inst = self.resolve(in_place=False)
-                if isinstance(resolved_inst, Future):
-                    ret = Future()
+                if isinstance(resolved_inst, PricingFuture):
+                    ret = PricingFuture()
                     resolved_inst.add_done_callback(lambda inst_f: ret.set_result(
                         object.__getattribute__(inst_f.result(), name)))
                 else:
@@ -97,9 +101,27 @@ class PriceableImpl(Priceable, metaclass=ABCMeta):
 
         rates is now the solved fixed rate
         """
-        return PricingContext.current.resolve_fields(self, in_place)
+        def handle_result(result: Optional[Union[ErrorValue, Priceable]]) -> Optional[Priceable]:
+            ret = None if in_place else result
+            if isinstance(result, ErrorValue):
+                _logger.error('Failed to resolve instrument fields: ' + result.error)
+                ret = self
+            elif result is None:
+                _logger.error('Unknown error resolving instrument fields')
+                ret = self
+            else:
+                if in_place:
+                    self.unresolved = copy.copy(self)
+                    self.from_instance(result)
 
-    def dollar_price(self) -> Union[FloatWithInfo, Future, SeriesWithInfo]:
+            return ret
+
+        if in_place and isinstance(PricingContext.current, HistoricalPricingContext):
+            raise RuntimeError('Cannot resolve in place under a HistoricalPricingContext')
+
+        return self.calc(ResolvedInstrumentValues, fn=handle_result)
+
+    def dollar_price(self) -> Union[FloatWithInfo, PricingFuture, SeriesWithInfo]:
         """
         Present value in USD
 
@@ -130,7 +152,7 @@ class PriceableImpl(Priceable, metaclass=ABCMeta):
         """
         return self.calc(DollarPrice)
 
-    def price(self) -> Union[FloatWithInfo, Future, SeriesWithInfo]:
+    def price(self) -> Union[FloatWithInfo, PricingFuture, SeriesWithInfo]:
         """
         Present value in local currency. Note that this is not yet supported on all instruments
 
@@ -145,13 +167,26 @@ class PriceableImpl(Priceable, metaclass=ABCMeta):
         """
         return self.calc(Price)
 
-    def calc(self, risk_measure: Union[RiskMeasure, Iterable[RiskMeasure]])\
-            -> Union[list, DataFrameWithInfo, ErrorValue, FloatWithInfo, Future, MultipleRiskMeasureFuture,
-                     SeriesWithInfo]:
+    def coordinates(self) -> Tuple[MarketDataCoordinate, ...]:
+        from gs_quant.api.gs.data import GsDataApi
+
+        def coordinates_for_asset(result: DataFrameWithInfo):
+            return tuple(itertools.chain.from_iterable(GsDataApi.get_many_coordinates(mkt_type=t,
+                                                                                      mkt_asset=a,
+                                                                                      return_type=MarketDataCoordinate,
+                                                                                      limit=10000)
+                                                       for t, a in zip(result.mkt_type, result.mkt_asset)))
+
+        return self.calc(MarketDataAssets, fn=coordinates_for_asset)
+
+    def calc(self, risk_measure: Union[RiskMeasure, Iterable[RiskMeasure]], fn=None)\
+            -> Union[DataFrameWithInfo, ErrorValue, FloatWithInfo, Priceable, PricingFuture, SeriesWithInfo,
+                     Tuple[MarketDataCoordinate, ...]]:
         """
         Calculate the value of the risk_measure
 
         :param risk_measure: the risk measure to compute, e.g. IRDelta (from gs_quant.risk)
+        :param fn: post-processing function (optional)
         :return: a float or dataframe, depending on whether the value is scalar or structured, or a future thereof
         (depending on how PricingContext is being used)
 
@@ -187,4 +222,20 @@ class PriceableImpl(Priceable, metaclass=ABCMeta):
 
         usd_delta_f and eur_delta_f are futures, usd_delta and eur_delta are dataframes
         """
-        return PricingContext.current.calc(self, risk_measure)
+        futures = {r: r.pricing_context.calc(self, r)
+                   for r in ((risk_measure,) if isinstance(risk_measure, RiskMeasure) else risk_measure)}
+        future = MultipleRiskMeasureFuture(futures) if len(futures) > 1 else futures[risk_measure]
+
+        if fn is not None:
+            ret = PricingFuture()
+
+            def cb(f):
+                try:
+                    ret.set_result(fn(f.result()))
+                except Exception as e:
+                    ret.set_exception(e)
+
+            future.add_done_callback(cb)
+            future = ret
+
+        return future.result() if not (PricingContext.current.is_entered or PricingContext.current.is_async) else future
