@@ -16,6 +16,7 @@ under the License.
 import datetime as dt
 import logging
 import pandas as pd
+from typing import Iterable, Union
 
 from .core import DataFrameWithInfo, ErrorValue, FloatWithInfo, StringWithInfo, sort_risk
 from gs_quant.base import InstrumentBase, RiskKey
@@ -24,10 +25,10 @@ from gs_quant.base import InstrumentBase, RiskKey
 _logger = logging.getLogger(__name__)
 
 
-def __dataframe_handler(field: str, mappings: tuple, result: dict, risk_key: RiskKey) -> DataFrameWithInfo:
-    records = [{k: datum[v] for k, v in mappings} for datum in result[field]]
+def __dataframe_handler(result: Iterable, mappings: tuple, risk_key: RiskKey) -> DataFrameWithInfo:
+    records = [{k: datum.get(v) or (None if v == 'value' else '') for k, v in mappings} for datum in result]
     df = pd.DataFrame.from_records(records)
-    return DataFrameWithInfo(risk_key, sort_risk(df, tuple(k for k, _ in mappings)))
+    return DataFrameWithInfo(sort_risk(df, tuple(k for k, _ in mappings)), risk_key=risk_key)
 
 
 def cashflows_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase) -> DataFrameWithInfo:
@@ -53,7 +54,7 @@ def cashflows_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBa
             date = dt.date.fromisoformat(value) if value else dt.date.max
             cashflow[field] = date
 
-    return __dataframe_handler('cashflows', mappings, result, risk_key)
+    return __dataframe_handler(result['cashflows'], mappings, risk_key)
 
 
 def error_handler(result: dict, risk_key: RiskKey, instrument: InstrumentBase) -> ErrorValue:
@@ -80,15 +81,45 @@ def number_and_unit_handler(result: dict, risk_key: RiskKey, _instrument: Instru
 
 def required_assets_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase):
     mappings = (('mkt_type', 'type'), ('mkt_asset', 'asset'))
-    return __dataframe_handler('requiredAssets', mappings, result, risk_key)
+    return __dataframe_handler(result['requiredAssets'], mappings, risk_key)
 
 
 def risk_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase) -> FloatWithInfo:
     return FloatWithInfo(risk_key, result.get('val', float('nan')), unit=result.get('unit'))
 
 
-def risk_by_class_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase) -> FloatWithInfo:
-    return FloatWithInfo(risk_key, sum(result.get('values', (float('nan'),))), unit=result.get('unit'))
+def risk_by_class_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase)\
+        -> Union[DataFrameWithInfo, FloatWithInfo]:
+    # TODO Remove this once we migrate parallel USD IRDelta measures
+    types = [c['type'] for c in result['classes']]
+    if len(types) <= 2 and len(set(types)) == 1:
+        return FloatWithInfo(risk_key, sum(result.get('values', (float('nan'),))), unit=result.get('unit'))
+    else:
+        classes = []
+        skip = []
+
+        crosses_idx = next((i for i, c in enumerate(result['classes']) if c['type'] == 'CROSSES'), None)
+        for idx, (clazz, value) in enumerate(zip(result['classes'], result['values'])):
+            mkt_type = clazz['type']
+            if 'SPIKE' in mkt_type or 'JUMP' in mkt_type:
+                skip.append(idx)
+
+                if crosses_idx is not None:
+                    result['classes'][crosses_idx]['value'] += value
+
+            clazz.update({'value': value})
+
+        for idx, clazz in enumerate(result['classes']):
+            if idx not in skip:
+                classes.append(clazz)
+
+        mappings = (
+            ('mkt_type', 'type'),
+            ('mkt_asset', 'asset'),
+            ('value', 'value')
+        )
+
+        return __dataframe_handler(classes, mappings, risk_key)
 
 
 def risk_vector_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase) -> DataFrameWithInfo:
@@ -103,7 +134,7 @@ def risk_vector_handler(result: dict, risk_key: RiskKey, _instrument: Instrument
         ('value', 'value')
     )
 
-    return __dataframe_handler('points', mappings, result, risk_key)
+    return __dataframe_handler(result['points'], mappings, risk_key)
 
 
 result_handlers = {
