@@ -32,6 +32,9 @@ def set_session():
     GsSession.use(Environment.PROD, 'client_id', 'secret')
     PricingCache.clear()
 
+    import gs_quant.markets.markets as markets
+    markets.close_market_date = mock.MagicMock(return_value=dt.date.today())
+
 
 def test_cache_addition_removal():
     set_session()
@@ -121,10 +124,9 @@ def test_cache_subset(mocker):
     ir_swap = IRSwap('Pay', '10y', 'DKK')
 
     values = [
-        {'$type': 'Risk', 'val': 0.01},
         {'$type': 'Risk', 'val': 0.01}
     ]
-    mocker.return_value = [[[values]]]
+    mocker.return_value = [[[values]], [[values]]]
 
     dates = (dt.date(2019, 10, 7), dt.date(2019, 10, 8))
     with HistoricalPricingContext(dates=dates, use_cache=True):
@@ -143,22 +145,6 @@ def test_cache_subset(mocker):
     assert cached2 is None
 
     values = [
-        {
-            '$type': 'RiskVector',
-            'asset': [0.01, 0.015],
-            'points': [
-                {'type': 'IR', 'asset': 'USD', 'class_': 'Swap', 'point': '1y'},
-                {'type': 'IR', 'asset': 'USD', 'class_': 'Swap', 'point': '2y'}
-            ]
-        },
-        {
-            '$type': 'RiskVector',
-            'asset': [0.01, 0.015],
-            'points': [
-                {'type': 'IR', 'asset': 'USD', 'class_': 'Swap', 'point': '1y'},
-                {'type': 'IR', 'asset': 'USD', 'class_': 'Swap', 'point': '2y'}
-            ]
-        },
         {
             '$type': 'RiskVector',
             'asset': [0.01, 0.015],
@@ -171,7 +157,7 @@ def test_cache_subset(mocker):
 
     # Check that we can return the same values from the cache, after calculating once (with return values set to None)
 
-    for return_values in ([[[values]]], None):
+    for return_values in ([[[values]], [[values]], [[values]]], None):
         mocker.return_value = return_values
 
         with HistoricalPricingContext(dates=dates, use_cache=True):
@@ -185,72 +171,29 @@ def test_cache_subset(mocker):
 
 @mock.patch.object(GsRiskApi, '_exec')
 def test_multiple_measures(mocker):
-    values = [
+    day = [
         [
-            [
-                {
-                    '$type': 'RiskVector',
-                    'asset': [0.01, 0.015],
-                    'points': [
-                        {'type': 'IR Vol', 'asset': 'USD-LIBOR-BBA', 'class_': 'Swap', 'point': '1y'},
-                        {'type': 'IR Vol', 'asset': 'USD-LIBOR-BBA', 'class_': 'Swap', 'point': '2y'}
-                    ]
-                },
-                {
-                    '$type': 'RiskVector',
-                    'asset': [0.01, 0.015],
-                    'points': [
-                        {'type': 'IR Vol', 'asset': 'USD-LIBOR-BBA', 'class_': 'Swap', 'point': '1y'},
-                        {'type': 'IR Vol', 'asset': 'USD-LIBOR-BBA', 'class_': 'Swap', 'point': '2y'}
-                    ]
-                },
-                {
-                    '$type': 'RiskVector',
-                    'asset': [0.01, 0.015],
-                    'points': [
-                        {'type': 'IR Vol', 'asset': 'USD-LIBOR-BBA', 'class_': 'Swap', 'point': '1y'},
-                        {'type': 'IR Vol', 'asset': 'USD-LIBOR-BBA', 'class_': 'Swap', 'point': '2y'}
-                    ]
-                }
-            ]
+            [{
+                '$type': 'RiskVector',
+                'asset': [0.01, 0.015],
+                'points': [
+                    {'type': 'IR Vol', 'asset': 'USD-LIBOR-BBA', 'class_': 'Swap', 'point': '1y'},
+                    {'type': 'IR Vol', 'asset': 'USD-LIBOR-BBA', 'class_': 'Swap', 'point': '2y'}
+                ]
+            }]
         ],
-        [
-            [
-                {
-                    '$type': 'RiskVector',
-                    'asset': [0.01, 0.015],
-                    'points': [
-                        {'type': 'IR', 'asset': 'USD', 'class_': 'Swap', 'point': '1y'},
-                        {'type': 'IR', 'asset': 'USD', 'class_': 'Swap', 'point': '2y'}
-                    ]
-                },
-                {
-                    '$type': 'RiskVector',
-                    'asset': [0.01, 0.015],
-                    'points': [
-                        {'type': 'IR', 'asset': 'USD', 'class_': 'Swap', 'point': '1y'},
-                        {'type': 'IR', 'asset': 'USD', 'class_': 'Swap', 'point': '2y'}
-                    ]
-                },
-                {
-                    '$type': 'RiskVector',
-                    'asset': [0.01, 0.015],
-                    'points': [
-                        {'type': 'IR', 'asset': 'USD', 'class_': 'Swap', 'point': '1y'},
-                        {'type': 'IR', 'asset': 'USD', 'class_': 'Swap', 'point': '2y'}
-                    ]
-                }
+        [{
+            '$type': 'RiskVector',
+            'asset': [0.01, 0.015],
+            'points': [
+                {'type': 'IR', 'asset': 'USD', 'class_': 'Swap', 'point': '1y'},
+                {'type': 'IR', 'asset': 'USD', 'class_': 'Swap', 'point': '2y'}
             ]
-        ],
-        [
-            [
-                {'$type': 'Risk', 'val': 0.01},
-                {'$type': 'Risk', 'val': 0.01},
-                {'$type': 'Risk', 'val': 0.01}
-            ]
-        ]
+        }],
+        [{'$type': 'Risk', 'val': 0.01}]
     ]
-    mocker.return_value = [values]
+
+    mocker.return_value = [day, day, day]
 
     set_session()
 
