@@ -17,8 +17,10 @@ under the License.
 from unittest import mock
 
 import copy
+import datetime as dt
 import pandas as pd
 
+from gs_quant.datetime.time import to_zulu_string
 import gs_quant.risk as risk
 from gs_quant.api.gs.risk import GsRiskApi
 from gs_quant.base import Priceable
@@ -27,7 +29,8 @@ from gs_quant.instrument import CommodSwap, EqForward, EqOption, FXOption, IRBas
     IRFloor
 from gs_quant.markets import PricingContext
 from gs_quant.session import Environment, GsSession
-from gs_quant.risk import PricingDateAndMarketDataAsOf, RiskRequestParameters
+from gs_quant.target.risk import PricingDateAndMarketDataAsOf, RiskPosition, RiskRequestParameters, \
+    APEXOptimizationRequest
 
 priceables = (
     CommodSwap('Electricity', '1y'),
@@ -47,6 +50,9 @@ def set_session():
     OAuth2Session.init = mock.MagicMock(return_value=None)
     GsSession.use(Environment.QA, 'client_id', 'secret')
 
+    import gs_quant.markets.markets as markets
+    markets.close_market_date = mock.MagicMock(return_value=dt.date.today())
+
 
 def structured_calc(mocker, priceable: Priceable, measure: risk.RiskMeasure):
     set_session()
@@ -68,13 +74,12 @@ def structured_calc(mocker, priceable: Priceable, measure: risk.RiskMeasure):
 
     current = PricingContext.current
     result = priceable.calc(measure)
-    assert result.equals(expected)
+    assert result.raw_value.equals(expected)
     risk_requests = (risk.RiskRequest(
-        positions=(risk.RiskPosition(instrument=priceable, quantity=1),),
+        positions=(RiskPosition(instrument=priceable, quantity=1),),
         measures=(measure,),
-        pricing_location=current.market_data_location,
         pricing_and_market_data_as_of=(PricingDateAndMarketDataAsOf(pricing_date=current.pricing_date,
-                                                                    market_data_as_of=current.market.as_of),),
+                                                                    market=current.market),),
         parameters=RiskRequestParameters(raw_results=True),
         wait_for_results=True),)
     mocker.assert_called_with(risk_requests)
@@ -88,11 +93,10 @@ def scalar_calc(mocker, priceable: Priceable, measure: risk.RiskMeasure):
     result = priceable.calc(measure)
     assert result == 0.01
     risk_requests = (risk.RiskRequest(
-        positions=(risk.RiskPosition(instrument=priceable, quantity=1),),
+        positions=(RiskPosition(instrument=priceable, quantity=1),),
         measures=(measure,),
-        pricing_location=current.market_data_location,
         pricing_and_market_data_as_of=(PricingDateAndMarketDataAsOf(pricing_date=current.pricing_date,
-                                                                    market_data_as_of=current.market.as_of),),
+                                                                    market=current.market),),
         parameters=RiskRequestParameters(raw_results=True),
         wait_for_results=True),)
     mocker.assert_called_with(risk_requests)
@@ -106,11 +110,10 @@ def price(mocker, priceable: Priceable):
     result = priceable.dollar_price()
     assert result == 0.01
     risk_requests = (risk.RiskRequest(
-        positions=(risk.RiskPosition(instrument=priceable, quantity=1),),
+        positions=(RiskPosition(instrument=priceable, quantity=1),),
         measures=(risk.DollarPrice,),
-        pricing_location=current.market_data_location,
         pricing_and_market_data_as_of=(PricingDateAndMarketDataAsOf(pricing_date=current.pricing_date,
-                                                                    market_data_as_of=current.market.as_of),),
+                                                                    market=current.market),),
         parameters=RiskRequestParameters(raw_results=True),
         wait_for_results=True),)
     mocker.assert_called_with(risk_requests)
@@ -211,3 +214,39 @@ def test_resolution():
     with mock.patch('gs_quant.api.gs.risk.GsRiskApi._exec') as mocker:
         mocker.return_value = [[[[{'$type': 'LegDefinition', 'fixedRate': 0.007}]]]]
         assert swap.fixed_rate == 0.007
+
+
+def test_create_pretrade_execution_optimization():
+    start_time = dt.datetime.utcnow()
+    duration = dt.timedelta(hours=8)
+    end_time = start_time + duration
+
+    positions = [{"assetId": "MA4B66MW5E27UANLXW6", "quantity": 350},
+                 {"assetId": "MA4B66MW5E27UAMFDDC", "quantity": 675}]
+
+    request = APEXOptimizationRequest(positions,
+                                      type="APEX",
+                                      executionStartTime=to_zulu_string(start_time),
+                                      executionEndTime=to_zulu_string(end_time),
+                                      waitForResults=False,
+                                      parameters={"urgency": "MEDIUM", "participationRate": 0.1})
+
+    set_session()
+    with mock.patch.object(GsSession.current, '_post') as mocker:
+        mock_response = {'optimizationId': 'LI0D2ND2JCFANFAN'}
+        mocker.return_value = mock_response
+        response = GsRiskApi.create_pretrade_execution_optimization(request)
+        GsSession.current._post.assert_called_with('/risk/execution/pretrade', request)
+        assert response == mock_response
+
+
+def test_get_pretrade_execution_optimization():
+    optimization_id = 'LI0D2ND2JCFANFAN'
+    mock_response = {'id': optimization_id, 'analytics': {}, 'status': 'Completed'}
+
+    set_session()
+    with mock.patch.object(GsSession.current, '_get') as mocker:
+        mocker.return_value = mock_response
+        response = GsRiskApi.get_pretrade_execution_optimization(optimization_id)
+        GsSession.current._get.assert_called_with('/risk/execution/pretrade/{}/results'.format(optimization_id))
+        assert response == mock_response
